orca r4514 - in trunk: . test/keystrokes/firefox



Author: joanied
Date: Mon Feb  9 15:38:30 2009
New Revision: 4514
URL: http://svn.gnome.org/viewvc/orca?rev=4514&view=rev

Log:
* test/keystrokes/firefox/uiuc_grid.py:
  test/keystrokes/firefox/line_nav_simple_form.py:
  test/keystrokes/firefox/xul_role_entry.py:
  test/keystrokes/firefox/xul_role_alert.py:
  test/keystrokes/firefox/sayAll_html_test_page.py: (removed)
  Updated regression tests. I also removed one sayAll test because
  it seems to stall the harness for some reason. Given that we have
  quite a few sayAll tests which examine the same conditions, I'd
  rather spend my time on Orca bugs rather than harness issues. :-)


Removed:
   trunk/test/keystrokes/firefox/sayAll_html_test_page.py
Modified:
   trunk/ChangeLog
   trunk/test/keystrokes/firefox/dojo_combo_box.py
   trunk/test/keystrokes/firefox/line_nav_simple_form.py
   trunk/test/keystrokes/firefox/uiuc_grid.py
   trunk/test/keystrokes/firefox/xul_role_alert.py
   trunk/test/keystrokes/firefox/xul_role_entry.py

Modified: trunk/test/keystrokes/firefox/dojo_combo_box.py
==============================================================================
--- trunk/test/keystrokes/firefox/dojo_combo_box.py	(original)
+++ trunk/test/keystrokes/firefox/dojo_combo_box.py	Mon Feb  9 15:38:30 2009
@@ -38,7 +38,7 @@
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
     "Tab to the first combo box", 
-    ["BUG? - Too verbose",
+    ["BUG? - Too verbose. This is true for all of the assertions, but I'm only marking it here.",
      "BRAILLE LINE:  'US State test 1 California $l'",
      "     VISIBLE:  'US State test 1 California $l', cursor=0",
      "SPEECH OUTPUT: 'US State test 1 combo box'",
@@ -51,8 +51,7 @@
 sequence.append(TypeAction("C"))
 sequence.append(utils.AssertPresentationAction(
     "Replace existing text with a 'C'", 
-    ["BUG? - Too verbose",
-     "BRAILLE LINE:  'US State test 1 California $l'",
+    ["BRAILLE LINE:  'US State test 1 California $l'",
      "     VISIBLE:  'US State test 1 California $l', cursor=0",
      "BRAILLE LINE:  'US State test 1 C $l'",
      "     VISIBLE:  'US State test 1 C $l', cursor=0",
@@ -84,8 +83,7 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "2. Down Arrow", 
-    ["BUG? - Too verbose",
-     "BRAILLE LINE:  'US State test 1 California $l'",
+    ["BRAILLE LINE:  'US State test 1 California $l'",
      "     VISIBLE:  'US State test 1 California $l', cursor=0",
      "BRAILLE LINE:  'US State test 1 C $l'",
      "     VISIBLE:  'US State test 1 C $l', cursor=0",
@@ -103,8 +101,7 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "3. Down Arrow", 
-    ["BUG? - Too verbose",
-     "BRAILLE LINE:  'US State test 1 Colorado $l'",
+    ["BRAILLE LINE:  'US State test 1 Colorado $l'",
      "     VISIBLE:  'US State test 1 Colorado $l', cursor=0",
      "BRAILLE LINE:  'US State test 1 C $l'",
      "     VISIBLE:  'US State test 1 C $l', cursor=0",
@@ -122,8 +119,7 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "4. Down Arrow", 
-    ["BUG? - Too verbose",
-     "BRAILLE LINE:  'US State test 1 Connecticut $l'",
+    ["BRAILLE LINE:  'US State test 1 Connecticut $l'",
      "     VISIBLE:  'US State test 1 Connecticut $l', cursor=0",
      "BRAILLE LINE:  'US State test 1 C $l'",
      "     VISIBLE:  'US State test 1 C $l', cursor=0",
@@ -138,8 +134,7 @@
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "1. Up Arrow", 
-    ["BUG? - Too verbose",
-     "BRAILLE LINE:  'US State test 1 Connecticut $l'",
+    ["BRAILLE LINE:  'US State test 1 Connecticut $l'",
      "     VISIBLE:  'US State test 1 Connecticut $l', cursor=0",
      "BRAILLE LINE:  'US State test 1 C $l'",
      "     VISIBLE:  'US State test 1 C $l', cursor=0",
@@ -157,8 +152,7 @@
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "2. Up Arrow", 
-    ["BUG? - Too verbose",
-     "BRAILLE LINE:  'US State test 1 Colorado $l'",
+    ["BRAILLE LINE:  'US State test 1 Colorado $l'",
      "     VISIBLE:  'US State test 1 Colorado $l', cursor=0",
      "BRAILLE LINE:  'US State test 1 C $l'",
      "     VISIBLE:  'US State test 1 C $l', cursor=0",
@@ -176,8 +170,7 @@
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "3. Up Arrow", 
-    ["BUG? - Too verbose",
-     "BRAILLE LINE:  'US State test 1 California $l'",
+    ["BRAILLE LINE:  'US State test 1 California $l'",
      "     VISIBLE:  'US State test 1 California $l', cursor=0",
      "BRAILLE LINE:  'US State test 1 C $l'",
      "     VISIBLE:  'US State test 1 C $l', cursor=0",

Modified: trunk/test/keystrokes/firefox/line_nav_simple_form.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_simple_form.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_simple_form.py	Mon Feb  9 15:38:30 2009
@@ -214,8 +214,7 @@
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "6. line Up",
-    ["KNOWN ISSUE - In Firefox 3.1 we get a caret-moved event that we're not getting in 3.0.x. These results are for 3.1",
-     "BRAILLE LINE:  '      $l'",
+    ["BRAILLE LINE:  '      $l'",
      "     VISIBLE:  '      $l', cursor=1",
      "BRAILLE LINE:  '      $l'",
      "     VISIBLE:  '      $l', cursor=1",

Modified: trunk/test/keystrokes/firefox/uiuc_grid.py
==============================================================================
--- trunk/test/keystrokes/firefox/uiuc_grid.py	(original)
+++ trunk/test/keystrokes/firefox/uiuc_grid.py	Mon Feb  9 15:38:30 2009
@@ -23,7 +23,7 @@
 sequence.append(KeyComboAction("Return"))
 sequence.append(WaitForDocLoad())
 
-sequence.append(PauseAction(3000))
+sequence.append(PauseAction(5000))
 
 ########################################################################
 # Tab to grid
@@ -36,9 +36,11 @@
      "     VISIBLE:  'E-mail List Sorted by Date Capti', cursor=1",
      "BRAILLE LINE:  '< > Email 0 Selected CheckBox 1 Read message Image Attachment Image Lowest priority Image John Smith Trip to Florida 2007-10-03 2K'",
      "     VISIBLE:  '< > Email 0 Selected CheckBox 1 ', cursor=1",
+     "BRAILLE LINE:  'Email 0 Selected CheckBox'",
+     "     VISIBLE:  'Email 0 Selected CheckBox', cursor=0",
      "SPEECH OUTPUT: 'E-mail List Sorted by Date caption'",
      "SPEECH OUTPUT: 'check box not checked 1 Read message image Attachment image Lowest priority image John Smith Trip to Florida 2007-10-03 2K'"]))
-    
+  
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.  
 #
@@ -47,11 +49,12 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "basic whereAmI", 
-    ["BRAILLE LINE:  '< > Email 0 Selected CheckBox 1 Read message Image Attachment Image Lowest priority Image John Smith Trip to Florida 2007-10-03 2K'",
-     "     VISIBLE:  '< > Email 0 Selected CheckBox 1 ', cursor=1",
-     "SPEECH OUTPUT: 'Email 0 Selected check box not checked'",
-     "SPEECH OUTPUT: ''"]))
-    
+    ["BUG? - speech info is useless",
+     "BRAILLE LINE:  'Email 0 Selected CheckBox'",
+     "     VISIBLE:  'Email 0 Selected CheckBox', cursor=0",
+     "SPEECH OUTPUT: 'panel'",
+     "SPEECH OUTPUT: 'cell'"]))
+
 ########################################################################
 # Move down grid
 #
@@ -59,10 +62,14 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Move down grid", 
-    ["BUG? - The initial speech seems hosed",
-     "BRAILLE LINE:  '< > Email 1 Selected CheckBox 2 New message Image Attachment Image Low priority Image Fred Jones Lunch on Friday 2007-12-03 1K'",
+    ["BRAILLE LINE:  '< > Email 1 Selected CheckBox 2 Cell New message Image Attachment Image Low priority Image Fred Jones Cell Lunch on Friday Cell 2007-12-03 Cell 1K Cell'",
      "     VISIBLE:  '< > Email 1 Selected CheckBox 2 ', cursor=1",
-     "SPEECH OUTPUT: '2New messageAttachmentLow priorityFred JonesLunch on Friday check box not checked 2 New message image Attachment image Low priority image Fred Jones Lunch on Friday 2007-12-03 1K'"]))
+     "BRAILLE LINE:  'Email 1 Selected CheckBox'",
+     "     VISIBLE:  'Email 1 Selected CheckBox', cursor=0",
+     "SPEECH OUTPUT: ''",
+     "SPEECH OUTPUT: 'Att column header'",
+     "SPEECH OUTPUT: '2 New message Attachment Low priority From Fred Jones Subject Lunch on Friday panel'",
+     "SPEECH OUTPUT: 'Email 1 Selected'"]))
     
 ########################################################################
 # Move right on second row 1
@@ -71,10 +78,7 @@
 sequence.append(KeyComboAction("Right"))
 sequence.append(utils.AssertPresentationAction(
     "Move right on second row 1", 
-    ["BUG? - The initial speech seems hosed",
-     "BRAILLE LINE:  '< > Email 1 Selected CheckBox 2 New message Image Attachment Image Low priority Image Fred Jones Lunch on Friday 2007-12-03 1K'",
-     "     VISIBLE:  '< > Email 1 Selected CheckBox 2 ', cursor=1",
-     "SPEECH OUTPUT: '2New messageAttachmentLow priorityFred JonesLunch on Friday check box not checked'"]))
+    ["BUG? - We're saying nothing here"]))
      
 ########################################################################
 # Move right on second row 2
@@ -85,6 +89,7 @@
     "Move right on second row 2", 
     ["BRAILLE LINE:  '< > Email 1 Selected CheckBox 2 Cell New message Image Attachment Image Low priority Image Fred Jones Cell Lunch on Friday Cell 2007-12-03 Cell 1K Cell'",
      "     VISIBLE:  '2 Cell New message Image Attachm', cursor=1",
+     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: '2'"]))
      
 ########################################################################
@@ -94,10 +99,10 @@
 sequence.append(KeyComboAction("Right"))
 sequence.append(utils.AssertPresentationAction(
     "Move right on second row 3", 
-    ["BRAILLE LINE:  '< > Email 0 Selected CheckBox 1 Cell Read message Image Attachment Image Lowest priority Image John Smith Cell Trip to Florida Cell 2007-10-03 Cell 2K Cell'",
-     "     VISIBLE:  '< > Email 0 Selected CheckBox 1 ', cursor=1",
-     "SPEECH OUTPUT: '1 Read message Attachment Lowest priority From John Smith Subject Trip to Florida panel'",
-     "SPEECH OUTPUT: 'Email 0 Selected'"]))
+    ["BRAILLE LINE:  'New message Image Attachment Image Low priority Image Fred Jones Cell Lunch on Friday Cell 2007-12-03 Cell 1K Cell'",
+     "     VISIBLE:  'New message Image Attachment Ima', cursor=1",
+     "SPEECH OUTPUT: ''",
+     "SPEECH OUTPUT: 'New message'"]))
     
 ########################################################################
 # Move down to third row 
@@ -106,10 +111,10 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Move down to third row", 
-    ["BRAILLE LINE:  '< > Email 1 Selected CheckBox 2 Cell New message Image Attachment Image Low priority Image Fred Jones Cell Lunch on Friday Cell 2007-12-03 Cell 1K Cell'",
-     "     VISIBLE:  '< > Email 1 Selected CheckBox 2 ', cursor=1",
-     "SPEECH OUTPUT: '2 New message Attachment Low priority From Fred Jones Subject Lunch on Friday panel'",
-     "SPEECH OUTPUT: 'Email 1 Selected'"]))
+    ["BRAILLE LINE:  'New message Image None Image Image Jane Johnson Cell Proposal for you to review Cell 2007-16-03 Cell 12K Cell'",
+     "     VISIBLE:  'New message Image None Image Ima', cursor=1",
+     "SPEECH OUTPUT: '3 New message None From Jane Johnson Subject Proposal for you to review panel'",
+     "SPEECH OUTPUT: 'New message'"]))
 
 ########################################################################
 # Close the demo

Modified: trunk/test/keystrokes/firefox/xul_role_alert.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_alert.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_alert.py	Mon Feb  9 15:38:30 2009
@@ -23,10 +23,11 @@
 sequence.append(TypeAction("javascript:alert('I am an alert')"))
 
 sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Return", 1000))
+sequence.append(KeyComboAction("Return"))
 sequence.append(utils.AssertPresentationAction(
     "Press Return to make the alert appear",
-    ["BRAILLE LINE:  'about:blank HtmlPane'",
+    ["KNOWN ISSUE - There is a Mozilla bug that causes us to not get window activate events, so we're not speaking the alert at the moment",
+     "BRAILLE LINE:  'about:blank HtmlPane'",
      "     VISIBLE:  'about:blank HtmlPane', cursor=1",
      "BRAILLE LINE:  'about:blank'",
      "     VISIBLE:  'about:blank', cursor=0",
@@ -55,7 +56,6 @@
      "     VISIBLE:  '" + utils.firefoxFrameNames + " Frame', cursor=1",
      "BRAILLE LINE:  'about:blank HtmlPane'",
      "     VISIBLE:  'about:blank HtmlPane', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: '" + utils.firefoxFrameNames + " frame'",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'about:blank html content'"]))

Modified: trunk/test/keystrokes/firefox/xul_role_entry.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_entry.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_entry.py	Mon Feb  9 15:38:30 2009
@@ -62,10 +62,9 @@
 sequence.append(KeyComboAction("BackSpace"))
 sequence.append(utils.AssertPresentationAction(
     "Backspace",
-    ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this is a test \$l'",
-     "     VISIBLE:  'this is a test $l', cursor=15",
+    ["BUG? - Braille is not updating correctly - it's off by one character. This is true for the next four assertions as well.",
      "BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this is a test \$l'",
-     "     VISIBLE:  'this is a test $l', cursor=14",
+     "     VISIBLE:  'this is a test $l', cursor=15",
      "SPEECH OUTPUT: 't'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -74,8 +73,6 @@
     "Backspace",
     ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this is a tes \$l'",
      "     VISIBLE:  'this is a tes $l', cursor=14",
-     "BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this is a tes \$l'",
-     "     VISIBLE:  'this is a tes $l', cursor=13",
      "SPEECH OUTPUT: 's'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -84,8 +81,6 @@
     "Backspace",
     ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this is a te \$l'",
      "     VISIBLE:  'this is a te $l', cursor=13",
-     "BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this is a te \$l'",
-     "     VISIBLE:  'this is a te $l', cursor=12",
      "SPEECH OUTPUT: 'e'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -94,8 +89,6 @@
     "Backspace",
     ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this is a t \$l'",
      "     VISIBLE:  'this is a t $l', cursor=12",
-     "BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this is a t \$l'",
-     "     VISIBLE:  'this is a t $l', cursor=11",
      "SPEECH OUTPUT: 't'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -104,8 +97,6 @@
     "Backspace",
     ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this is a  \$l'",
      "     VISIBLE:  'this is a  $l', cursor=11",
-     "BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this is a  \$l'",
-     "     VISIBLE:  'this is a  $l', cursor=10",
      "SPEECH OUTPUT: 'space'"]))
 
 ########################################################################
@@ -116,8 +107,7 @@
 sequence.append(KeyComboAction("<Control>BackSpace"))
 sequence.append(utils.AssertPresentationAction(
     "Control Backspace",
-    ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this is a \$l'",
-     "     VISIBLE:  'this is a $l', cursor=9",
+    ["BUG? - Braille is not updating correctly - it's off by one word. This is true for the next two assertions as well.",
      "BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this is a \$l'",
      "     VISIBLE:  'this is a $l', cursor=9",
      "SPEECH OUTPUT: 'a'"]))
@@ -128,8 +118,6 @@
     "Control Backspace",
     ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this is  \$l'",
      "     VISIBLE:  'this is  $l', cursor=6",
-     "BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this is  \$l'",
-     "     VISIBLE:  'this is  $l', cursor=6",
      "SPEECH OUTPUT: 'is '"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -138,13 +126,15 @@
     "Control Backspace",
     ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this  \$l'",
      "     VISIBLE:  'this  $l', cursor=1",
-     "BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this  \$l'",
-     "     VISIBLE:  'this  $l', cursor=1",
      "SPEECH OUTPUT: 'this '"]))
 
 ########################################################################
-# Type "so is this"
+# Due to a bug, we'll stop getting caret-moved events if we don't move
+# focus out of and back into this entry. Therefore, Tab to the next
+# entry, Shift+Tab back, and type "so is this"
 #
+sequence.append(KeyComboAction("Tab"))
+sequence.append(KeyComboAction("<Shift>Tab"))
 sequence.append(TypeAction("so is this"))
 
 ########################################################################
@@ -209,7 +199,7 @@
 sequence.append(KeyComboAction("<Control>Delete"))
 sequence.append(utils.AssertPresentationAction(
     "Control Delete",
-    ["BUG? - We are speaking the new caret location -- we land on a space -- rather than the word that was just deleted.",
+    ["BUG? - We are speaking the new caret location -- we land on a space -- rather than the word that was just deleted. This is true for the next assertion as well.",
      "BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog so is this \$l'",
      "     VISIBLE:  'so is this $l', cursor=3",
      "SPEECH OUTPUT: 'space'"]))
@@ -218,8 +208,7 @@
 sequence.append(KeyComboAction("<Control>Delete"))
 sequence.append(utils.AssertPresentationAction(
     "Control Delete",
-    ["BUG? - We are speaking the new caret location -- we land on a space -- rather than the word that was just deleted.",
-     "BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog  is this \$l'",
+    ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog  is this \$l'",
      "     VISIBLE:  ' is this $l', cursor=4",
      "SPEECH OUTPUT: 'space'"]))
 
@@ -230,51 +219,42 @@
 sequence.append(KeyComboAction("Delete", 500))
 sequence.append(utils.AssertPresentationAction(
     "Delete",
-    ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog  this \$l'",
-     "     VISIBLE:  ' this $l', cursor=1",
-     "SPEECH OUTPUT: 'space'"]))
-
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Delete", 500))
-sequence.append(utils.AssertPresentationAction(
-    "Delete",
-    ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this \$l'",
-     "     VISIBLE:  'this $l', cursor=1",
+    ["BUG? - Braille is not updating correctly - it's off by one character. This is true for the next three assertions as well.",
+     "BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog  this \$l'",
+     "     VISIBLE:  ' this $l', cursor=2",
      "SPEECH OUTPUT: 't'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Delete", 500))
 sequence.append(utils.AssertPresentationAction(
     "Delete",
-    ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog his \$l'",
-     "     VISIBLE:  'his $l', cursor=1",
+    ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog this \$l'",
+     "     VISIBLE:  'this $l', cursor=2",
      "SPEECH OUTPUT: 'h'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Delete", 500))
 sequence.append(utils.AssertPresentationAction(
     "Delete",
-    ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog is \$l'",
-     "     VISIBLE:  'is $l', cursor=1",
+    ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog his \$l'",
+     "     VISIBLE:  'his $l', cursor=2",
      "SPEECH OUTPUT: 'i'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Delete", 500))
 sequence.append(utils.AssertPresentationAction(
     "Delete",
-    ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog s \$l'",
-     "     VISIBLE:  's $l', cursor=1",
+    ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog is \$l'",
+     "     VISIBLE:  'is $l', cursor=2",
      "SPEECH OUTPUT: 's'"]))
 
 ########################################################################
 # Press Shift+Tab 3 times to get to the Description Entry.
 #
-sequence.append(KeyComboAction("<Shift>Tab"))
-sequence.append(KeyComboAction("<Shift>Tab"))
 sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("<Shift>Tab"))
+sequence.append(KeyComboAction("<Alt>d"))
 sequence.append(utils.AssertPresentationAction(
-    "Shift+Tab to Description",
+    "Alt+D to Description",
     ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application " + dialogName + " Dialog  \$l'",
      "     VISIBLE:  ' $l', cursor=1",
      "SPEECH OUTPUT: ''",
@@ -230,51 +219,42 @@
 
 ########################################################################
-# Press Shift+Tab 3 times to get to the Description Entry.
+# Press Alt+D times to get to the Description Entry.
 #



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]